@@ -1,12 +1,10 @@
 # Copyright (c) 2021 Cisco Systems, Inc. and its affiliates
 # All rights reserved.
 
-import requests
 
 from soufi import exceptions, finder
 
 NPM_REGISTRY = 'https://registry.npmjs.org/'
-API_TIMEOUT = 30  # seconds
 
 
 class NPMFinder(finder.SourceFinder):
@@ -19,15 +17,15 @@ class NPMFinder(finder.SourceFinder):
 
     def _find(self):
         source_url = self.get_source_url()
-        return NPMDiscoveredSource([source_url])
+        return NPMDiscoveredSource([source_url], timeout=self.timeout)
 
     def get_source_url(self):
         """Get the URL from the JSON info for the NPM package."""
         url = f"{NPM_REGISTRY}{self.name}/{self.version}"
-        response = requests.get(url, timeout=API_TIMEOUT)
-        if response.status_code != requests.codes.ok:
+        try:
+            data = self.get_url(url).json()
+        except exceptions.DownloadError:
             raise exceptions.SourceNotFound
-        data = response.json()
         return data['dist']['tarball']
 
 
